## 1.0.0 (2023-02-06)

### Refactor

- finish pydap to dapclient transition in documentation and finished add client only tests from pydap

## 0.1.2 (2023-01-16)

### Refactor

- refactor using refurb and pylint

## 0.1.1 (2023-01-07)

## 0.1.0 (2023-01-02)

### Feat

- initial commit
